*$ CREATE WVLNSH.FOR
*COPY WVLNSH
*
*=== Wvlnsh ===========================================================*
*
      SUBROUTINE WVLNSH ( EKPHOT, WVLNGT, MREG  , MMAT  , NWVSHP,
     &                    WVSHPH, DWVSHP, MXWSPH )

      INCLUDE '(DBLPRC)'
      INCLUDE '(DIMPAR)'
      INCLUDE '(IOUNIT)'
*
*----------------------------------------------------------------------*
*                                                                      *
*     Copyright (C) 1997-2010      by    Alfredo Ferrari & Paola Sala  *
*     All Rights Reserved.                                             *
*                                                                      *
*                                                                      *
*     WaVe LeNgth SHifted photon production:                           *
*                                                                      *
*     Created on 21 september 1997 by    Alfredo Ferrari & Paola Sala  *
*                                                   Infn - Milan       *
*                                                                      *
*     Last change on 16-Dec-10     by    Alfredo Ferrari               *
*                                                                      *
*    Note the wavelength is always assumed to be the vacuum one        *
*                                                                      *
*    Input variables:                                                  *
*                                                                      *
*          Ekphot = absorbed photon energy     (GeV)                   *
*          Wvlngt = absorbed photon wave-length (cm)                   *
*          Mreg   = current region                                     *
*          Mmat   = current material                                   *
*          Mxwsph = maximum number of secondary photons                *
*                                                                      *
*                                                                      *
*    Output variables:                                                 *
*                                                                      *
*          Nwvshp = number of produced secondary photons               *
*       Wvshph(i) > 0 -> energy    (GeV) of the i_th produced photon   *
*                 < 0 -> wavelength (cm) of the i_th produced photon   *
*       Dwvshp(i) = production delay (s) of the i_th produced photon   *
*                                                                      *
*----------------------------------------------------------------------*
* 
      INCLUDE '(FLKMAT)'
	  DIMENSION WVSHPH (MXWSPH), DWVSHP (MXWSPH)
	  IF ( MREG .EQ. 5 ) THEN 
	  	IF (EKPHOT .EQ. 20.0D-09) THEN
           NWVSHP = 4
          WVSHPH(1) = 4.0D-09
          DWVSHP(1)= 0
          WVSHPH(2) = 6.D-09
          DWVSHP(2)= 0
          WVSHPH(3) = 2.D-09
          DWVSHP(3)= 0
          WVSHPH(4) = 1.5D-09
          DWVSHP(4)= 0
	  	END IF
          END IF
	  RETURN
*=== End of subroutine Wvlnsh =========================================*
	  END

